==> himach_0.3.1.tar.gz: himach/tests/testthat/_snaps/utils.md <==
# Default aircraft data loads

    WAoAAAACAAQCAgACAwAAAAMTAAAADAAAABAAAAAEAAQACQAAAANNMjIABAAJAAAABU0xNl85
    AAQACQAAAARNMDg0AAQACQAAAAhNMjJfdGVzdAAAABAAAAAEAAQACQAAAAhTU1QgTTIuMgAE
    AAkAAAAMU1NUIE0xLjYgOC44AAQACQAAAAk3NzctMzAwRVIABAAJAAAADVRlc3Qtb25seSBT
    U1QAAAAOAAAABEABmZmZmZmaP/mZmZmZmZo/6uFHrhR64UABmZmZmZmaAAAADgAAAAQ/7mZm
    ZmZmZj/uZmZmZmZmP+rhR64UeuE/4AAAAAAAAAAAAA4AAAAEQHXgAAAAAABAdeAAAAAAAEB1
    4AAAAAAAQHXgAAAAAAAAAAAOAAAABD+5mZmZmZmaP7mZmZmZmZo/uZmZmZmZmkAAAAAAAAAA
    AAAADgAAAARAwEKAAAAAAEDBMAAAAAAAQMqogAAAAABAj0AAAAAAAAAAABAAAAAEAAQACQAA
    AE5CYXNlZCBvbiBCb29tIE92ZXJ0dXJlIChwdWJsaWMgd2Vic2l0ZSksIHN1YnNvbmljIGNy
    dWlzZSBmcm9tIEFlcmlvbiB3aWtpcGVkaWEABAAJAAAANkJhc2VkIG9uIEFlcmlvbiBBUzIg
    KHdpa2lwZWRpYSksIGluYy4gc3Vic29uaWMgY3J1aXNlIAAEAAkAAAAQU3Vic29uaWMgZXhh
    bXBsZQAEAAkAAAA7U3RyYW5nZSBwZXJmb3JtYW5jZSwgZm9yIHRlc3RzIHRvIHdvcmsgb3Zl
    ciBzbWFsbCBkaXN0YW5jZXMAAAAOAAAABECiQMzMzMzNQJqMzMzMzM1Ai+Cj1wo9cECiQMzM
    zMzNAAAADgAAAARAj4czMzMzM0CPhzMzMzMzQIvgo9cKPXBAgJgAAAAAAAAAAA4AAAAEQJoi
    mZmZmZpAlSgzMzMzM0CL4KPXCj1wQJZmzMzMzM0AAAAOAAAABD+uTZNk2TZRP5aIiIiIiIoA
    AAAAAAAAAD92a11mtdZtAAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAwABAAJAAAAAmlk
    AAQACQAAAAR0eXBlAAQACQAAAApvdmVyX3NlYV9NAAQACQAAAAtvdmVyX2xhbmRfTQAEAAkA
    AAAKYXJyZGVwX2twaAAEAAkAAAAJYWNjZWxfTXBtAAQACQAAAAhyYW5nZV9rbQAEAAkAAAAF
    bm90ZXMABAAJAAAADG92ZXJfc2VhX2twaAAEAAkAAAANb3Zlcl9sYW5kX2twaAAEAAkAAAAJ
    dHJhbnNfa3BoAAQACQAAAAd0cmFuc19oAAAEAgAAAAEABAAJAAAABWNsYXNzAAAAEAAAAAEA
    BAAJAAAACmRhdGEuZnJhbWUAAAQCAAAAAQAEAAkAAAAJcm93Lm5hbWVzAAAADQAAAAKAAAAA
    /////AAABAIAAAABAAQACQAAAAthaXJjcmFmdFNldAAAABAAAAABAAQACQAAAA10ZXN0X2Fp
    cmNyYWZ0AAAA/g==

# Aircraft data loads

    WAoAAAACAAQCAgACAwAAAAMTAAAACwAAABAAAAACAAQACQAAAAR0ZXN0AAQACQAAAAR0ZXN0
    AAAAEAAAAAIABAAJAAAADXRlc3QgYWlyY3JhZnQABAAJAAAADXRlc3QgYWlyY3JhZnQAAAAO
    AAAAAkAAAAAAAAAAQAAAAAAAAAAAAAAOAAAAAj/szMzMzMzNP+zMzMzMzM0AAAAOAAAAAj/J
    mZmZmZmaP8mZmZmZmZoAAAAOAAAAAkBywAAAAAAAQHLAAAAAAAAAAAAOAAAAAkC3cAAAAAAA
    QLdwAAAAAAAAAAAOAAAAAkCgmAAAAAAAQKCYAAAAAAAAAAAOAAAAAkCN3mZmZmZnQI3eZmZm
    ZmcAAAAOAAAAAkCYD5mZmZmaQJgPmZmZmZoAAAAOAAAAAj+Z0DadA2nRP5nQNp0DadEAAAQC
    AAAAAQAEAAkAAAAFbmFtZXMAAAAQAAAACwAEAAkAAAACaWQABAAJAAAABHR5cGUABAAJAAAA
    Cm92ZXJfc2VhX00ABAAJAAAAC292ZXJfbGFuZF9NAAQACQAAAAlhY2NlbF9NcG0ABAAJAAAA
    CmFycmRlcF9rcGgABAAJAAAACHJhbmdlX2ttAAQACQAAAAxvdmVyX3NlYV9rcGgABAAJAAAA
    DW92ZXJfbGFuZF9rcGgABAAJAAAACXRyYW5zX2twaAAEAAkAAAAHdHJhbnNfaAAABAIAAAAB
    AAQACQAAAAlyb3cubmFtZXMAAAANAAAAAoAAAAD////+AAAEAgAAAAEABAAJAAAABWNsYXNz
    AAAAEAAAAAEABAAJAAAACmRhdGEuZnJhbWUAAAQCAAAAAQAEAAkAAAALYWlyY3JhZnRTZXQA
    AAAQAAAAAQAEAAkAAAAORHVtbXkgYWlyY3JhZnQAAAD+

# Default airport data loads

    WAoAAAACAAQCAgACAwAAAAMTAAAABAAAABAAAAABAAQACQAAAARFR0xMAAAADgAAAAFASbw8
    nuy/sQAAAA4AAAABv92QcPvrnkkAAAIOAAAAAr/dkHD7655JQEm8PJ7sv7EAAAQCAAAAAQAE
    AAkAAAADZGltAAAADQAAAAIAAAABAAAAAgAABAIAAAABAAQACQAAAAhkaW1uYW1lcwAAABMA
    AAACAAAAEAAAAAEABAAJAAAAATEAAAAQAAAAAgAEAAkAAAABWAAEAAkAAAABWQAAAP4AAAQC
    AAAAAQAEAAkAAAAFbmFtZXMAAAAQAAAABAAEAAkAAAAGQVBJQ0FPAAQACQAAAANsYXQABAAJ
    AAAABGxvbmcABAAJAAAAB2FwX2xvY3MAAAQCAAAAAQAEAAkAAAAJcm93Lm5hbWVzAAAADQAA
    AAKAAAAA/////wAABAIAAAABAAQACQAAAAVjbGFzcwAAABAAAAAEAAQACQAAAAtzcGVjX3Ri
    bF9kZgAEAAkAAAAGdGJsX2RmAAQACQAAAAN0YmwABAAJAAAACmRhdGEuZnJhbWUAAAD+

# Airport data loads

    WAoAAAACAAQCAgACAwAAAAMTAAAABAAAABAAAAACAAQACQAAAARURVNUAAQACQAAAAV0ZXN0
    MgAAAA4AAAACQCQAAAAAAABAFAAAAAAAAAAAAA4AAAACQCQAAAAAAADAFAAAAAAAAAAAAg4A
    AAAEQCQAAAAAAADAFAAAAAAAAEAkAAAAAAAAQBQAAAAAAAAAAAQCAAAAAQAEAAkAAAADZGlt
    AAAADQAAAAIAAAACAAAAAgAABAIAAAABAAQACQAAAAhkaW1uYW1lcwAAABMAAAACAAAAEAAA
    AAIABAAJAAAAATEABAAJAAAAATIAAAAQAAAAAgAEAAkAAAABWAAEAAkAAAABWQAAAP4AAAQC
    AAAAAQAEAAkAAAAFbmFtZXMAAAAQAAAABAAEAAkAAAAGQVBJQ0FPAAQACQAAAANsYXQABAAJ
    AAAABGxvbmcABAAJAAAAB2FwX2xvY3MAAAQCAAAAAQAEAAkAAAAFY2xhc3MAAAAQAAAAAQAE
    AAkAAAAKZGF0YS5mcmFtZQAABAIAAAABAAQACQAAAAlyb3cubmFtZXMAAAANAAAAAoAAAAD/
    ///+AAAA/g==

==> himach_1.0.0.tar.gz: himach/tests/testthat/_snaps/utils.md <==
# Default aircraft data loads

    WAoAAAACAAQCAgACAwAAAAMTAAAADAAAABAAAAAEAAQACQAAAANNMjIABAAJAAAABU0xNl85
    AAQACQAAAARNMDg0AAQACQAAAAhNMjJfdGVzdAAAABAAAAAEAAQACQAAAAhTU1QgTTIuMgAE
    AAkAAAAMU1NUIE0xLjYgOC44AAQACQAAAAk3NzctMzAwRVIABAAJAAAADVRlc3Qtb25seSBT
    U1QAAAAOAAAABEABmZmZmZmaP/mZmZmZmZo/6uFHrhR64UABmZmZmZmaAAAADgAAAAQ/7mZm
    ZmZmZj/uZmZmZmZmP+rhR64UeuE/4AAAAAAAAAAAAA4AAAAEQHXgAAAAAABAdeAAAAAAAEB1
    4AAAAAAAQHXgAAAAAAAAAAAOAAAABD+5mZmZmZmaP7mZmZmZmZo/uZmZmZmZmkAAAAAAAAAA
    AAAADgAAAARAwEKAAAAAAEDBMAAAAAAAQMqogAAAAABAj0AAAAAAAAAAABAAAAAEAAQACQAA
    AE5CYXNlZCBvbiBCb29tIE92ZXJ0dXJlIChwdWJsaWMgd2Vic2l0ZSksIHN1YnNvbmljIGNy
    dWlzZSBmcm9tIEFlcmlvbiB3aWtpcGVkaWEABAAJAAAANkJhc2VkIG9uIEFlcmlvbiBBUzIg
    KHdpa2lwZWRpYSksIGluYy4gc3Vic29uaWMgY3J1aXNlIAAEAAkAAAAQU3Vic29uaWMgZXhh
    bXBsZQAEAAkAAAA7U3RyYW5nZSBwZXJmb3JtYW5jZSwgZm9yIHRlc3RzIHRvIHdvcmsgb3Zl
    ciBzbWFsbCBkaXN0YW5jZXMAAAAOAAAABECiQMzMzMzNQJqMzMzMzM1Ai+Cj1wo9cECiQMzM
    zMzNAAAADgAAAARAj4czMzMzM0CPhzMzMzMzQIvgo9cKPXBAgJgAAAAAAAAAAA4AAAAEQJoi
    mZmZmZpAlSgzMzMzM0CL4KPXCj1wQJZmzMzMzM0AAAAOAAAABD+uTZNk2TZRP5aIiIiIiIoA
    AAAAAAAAAD92a11mtdZtAAAEAgAAAAEABAAJAAAABW5hbWVzAAAAEAAAAAwABAAJAAAAAmlk
    AAQACQAAAAR0eXBlAAQACQAAAApvdmVyX3NlYV9NAAQACQAAAAtvdmVyX2xhbmRfTQAEAAkA
    AAAKYXJyZGVwX2twaAAEAAkAAAAJYWNjZWxfTXBtAAQACQAAAAhyYW5nZV9rbQAEAAkAAAAF
    bm90ZXMABAAJAAAADG92ZXJfc2VhX2twaAAEAAkAAAANb3Zlcl9sYW5kX2twaAAEAAkAAAAJ
    dHJhbnNfa3BoAAQACQAAAAd0cmFuc19oAAAEAgAAAAEABAAJAAAABWNsYXNzAAAAEAAAAAEA
    BAAJAAAACmRhdGEuZnJhbWUAAAQCAAAAAQAEAAkAAAAJcm93Lm5hbWVzAAAADQAAAAKAAAAA
    /////AAABAIAAAABAAQACQAAAAthaXJjcmFmdFNldAAAABAAAAABAAQACQAAAA10ZXN0X2Fp
    cmNyYWZ0AAAA/g==

# Aircraft data loads

    WAoAAAACAAQCAgACAwAAAAMTAAAACwAAABAAAAACAAQACQAAAAR0ZXN0AAQACQAAAAR0ZXN0
    AAAAEAAAAAIABAAJAAAADXRlc3QgYWlyY3JhZnQABAAJAAAADXRlc3QgYWlyY3JhZnQAAAAO
    AAAAAkAAAAAAAAAAQAAAAAAAAAAAAAAOAAAAAj/szMzMzMzNP+zMzMzMzM0AAAAOAAAAAj/J
    mZmZmZmaP8mZmZmZmZoAAAAOAAAAAkBywAAAAAAAQHLAAAAAAAAAAAAOAAAAAkC3cAAAAAAA
    QLdwAAAAAAAAAAAOAAAAAkCgmAAAAAAAQKCYAAAAAAAAAAAOAAAAAkCN3mZmZmZnQI3eZmZm
    ZmcAAAAOAAAAAkCYD5mZmZmaQJgPmZmZmZoAAAAOAAAAAj+Z0DadA2nRP5nQNp0DadEAAAQC
    AAAAAQAEAAkAAAAFbmFtZXMAAAAQAAAACwAEAAkAAAACaWQABAAJAAAABHR5cGUABAAJAAAA
    Cm92ZXJfc2VhX00ABAAJAAAAC292ZXJfbGFuZF9NAAQACQAAAAlhY2NlbF9NcG0ABAAJAAAA
    CmFycmRlcF9rcGgABAAJAAAACHJhbmdlX2ttAAQACQAAAAxvdmVyX3NlYV9rcGgABAAJAAAA
    DW92ZXJfbGFuZF9rcGgABAAJAAAACXRyYW5zX2twaAAEAAkAAAAHdHJhbnNfaAAABAIAAAAB
    AAQACQAAAAlyb3cubmFtZXMAAAANAAAAAoAAAAD////+AAAEAgAAAAEABAAJAAAABWNsYXNz
    AAAAEAAAAAEABAAJAAAACmRhdGEuZnJhbWUAAAQCAAAAAQAEAAkAAAALYWlyY3JhZnRTZXQA
    AAAQAAAAAQAEAAkAAAAORHVtbXkgYWlyY3JhZnQAAAD+

# Default airport data loads

    WAoAAAACAAQDAQACAwAAAAMTAAAABAAAABAAAAABAAQACQAAAARFR0xMAAAADgAAAAFASbw8
    nuy/sQAAAA4AAAABv92QcPvrnkkAAAIOAAAAAr/dkHD7655JQEm8PJ7sv7EAAAQCAAAAAQAE
    AAkAAAADZGltAAAADQAAAAIAAAABAAAAAgAABAIAAAABAAQACQAAAAhkaW1uYW1lcwAAABMA
    AAACAAAA/gAAABAAAAACAAQACQAAAAFYAAQACQAAAAFZAAAA/gAABAIAAAABAAQACQAAAAVu
    YW1lcwAAABAAAAAEAAQACQAAAAZBUElDQU8ABAAJAAAAA2xhdAAEAAkAAAAEbG9uZwAEAAkA
    AAAHYXBfbG9jcwAABAIAAAABAAQACQAAAAlyb3cubmFtZXMAAAANAAAAAoAAAAD/////AAAE
    AgAAAAEABAAJAAAABWNsYXNzAAAAEAAAAAQABAAJAAAAC3NwZWNfdGJsX2RmAAQACQAAAAZ0
    YmxfZGYABAAJAAAAA3RibAAEAAkAAAAKZGF0YS5mcmFtZQAAAP4=

# Airport data loads

    WAoAAAACAAQDAQACAwAAAAMTAAAABAAAABAAAAACAAQACQAAAARURVNUAAQACQAAAAV0ZXN0
    MgAAAA4AAAACQCQAAAAAAABAFAAAAAAAAAAAAA4AAAACQCQAAAAAAADAFAAAAAAAAAAAAg4A
    AAAEQCQAAAAAAADAFAAAAAAAAEAkAAAAAAAAQBQAAAAAAAAAAAQCAAAAAQAEAAkAAAADZGlt
    AAAADQAAAAIAAAACAAAAAgAABAIAAAABAAQACQAAAAhkaW1uYW1lcwAAABMAAAACAAAA/gAA
    ABAAAAACAAQACQAAAAFYAAQACQAAAAFZAAAA/gAABAIAAAABAAQACQAAAAVuYW1lcwAAABAA
    AAAEAAQACQAAAAZBUElDQU8ABAAJAAAAA2xhdAAEAAkAAAAEbG9uZwAEAAkAAAAHYXBfbG9j
    cwAABAIAAAABAAQACQAAAAVjbGFzcwAAABAAAAABAAQACQAAAApkYXRhLmZyYW1lAAAEAgAA
    AAEABAAJAAAACXJvdy5uYW1lcwAAAA0AAAACgAAAAP////4AAAD+
